import os
import subprocess
import sys
import json
import tempfile
from pathlib import Path
from typing import Any, NoReturn, Union

from . import node


TEMP_DIR = Path(tempfile.gettempdir()) / 'pyright-python-langserver'


def main(*args: str, **kwargs: Any) -> int:
    return run(*args, **kwargs).returncode


def run(
    *args: str,
    **kwargs: Any,
) -> Union['subprocess.CompletedProcess[bytes]', 'subprocess.CompletedProcess[str]']:
    TEMP_DIR.mkdir(exist_ok=True, parents=True)

    version = os.environ.get('PYRIGHT_PYTHON_FORCE_VERSION')
    if version is None:
        version = node.latest('pyright')

    pkg = TEMP_DIR / 'node_modules' / 'pyright' / 'package.json'
    if pkg.exists():
        current_version = json.loads(pkg.read_text()).get('version')
    else:
        current_version = None

    # TODO: use the same install location as the pyright CLI
    if current_version is None or current_version != version:
        node.run('npm', 'install', f'pyright@{version}', cwd=str(TEMP_DIR), check=True)

    binary = TEMP_DIR / 'node_modules' / 'pyright' / 'langserver.index.js'
    if not binary.exists():
        raise RuntimeError(f'Expected language server entrypoint: {binary} to exist')

    return node.run('node', str(binary), '--', *args, **kwargs)


def entrypoint() -> NoReturn:
    sys.exit(main(*sys.argv[1:]))


if __name__ == '__main__':
    entrypoint()



import os
import sys
import logging
import subprocess
from typing import List, NoReturn, Union, Any

from . import node
from .utils import env_to_bool


__all__ = (
    'run',
    'main',
)

log: logging.Logger = logging.getLogger(__name__)


def main(args: List[str], **kwargs: Any) -> int:
    return run(*args, **kwargs).returncode


def run(
    *args: str, **kwargs: Any
) -> Union['subprocess.CompletedProcess[bytes]', 'subprocess.CompletedProcess[str]']:
    version = os.environ.get('PYRIGHT_PYTHON_FORCE_VERSION')
    if version is None:
        version = node.latest('pyright')

    npx = node.version('npx')
    if npx[0] >= 7:
        pre_args = ['--yes']

        if not env_to_bool('PYRIGHT_PYTHON_VERBOSE', default=False):
            pre_args.insert(0, '--silent')
    else:
        pre_args = []

    if args and pre_args:
        args = ('--', *args)

    return node.run('npx', *pre_args, f'pyright@{version}', *args, **kwargs)


def entrypoint() -> NoReturn:
    sys.exit(main(sys.argv[1:]))



# -*- coding: utf-8 -*-
# pyright: reportUnusedImport=false

__title__ = 'pyright'
__author__ = 'RobertCraigie'
__license__ = 'MIT'
__copyright__ = 'Copyright 2021 Robert Craigie'
__version__ = '0.0.12'


import os
from . import errors as errors
from .cli import *


if os.environ.get('PYRIGHT_PYTHON_DEBUG'):
    import logging

    logging.basicConfig(
        format='%(asctime)-15s - %(levelname)s - %(name)s - %(message)s'
    )
    logging.getLogger('pyright').setLevel(logging.DEBUG)
